# Text Emotion

# Introduction

### Supported Languages

# Installation

You can install emotion using:

    $ pip install text-emotion

# Usage

```python
from text_emotion import Detector

detector = Detector()

print(detector.detect("Hello, I am so happy!", emotion_language="fr"))
```